==> onyx-2.0.0.tgz: include/libonyx/nxo_integer.h <==
/******************************************************************************
 *
 * Copyright (C) 1996-2001 Jason Evans <jasone@canonware.com>.
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice(s), this list of conditions and the following disclaimer
 *    unmodified other than the allowable addition of one or more
 *    copyright notices.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice(s), this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER(S) ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER(S) BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************
 *
 * Version: 2.0.0
 *
 ******************************************************************************/

#ifndef _CW_USE_INLINES
void	nxo_integer_new(cw_nxo_t *a_nxo, cw_nxoi_t a_val);
cw_nxoi_t nxo_integer_get(cw_nxo_t *a_nxo);
void	nxo_integer_set(cw_nxo_t *a_nxo, cw_nxoi_t a_val);
#endif

#if (defined(_CW_USE_INLINES) || defined(_NXO_INTEGER_C_))
_CW_INLINE void
nxo_integer_new(cw_nxo_t *a_nxo, cw_nxoi_t a_val)
{
	_cw_check_ptr(a_nxo);

	nxo_p_new(a_nxo, NXOT_INTEGER);
	a_nxo->o.integer.i = a_val;
}

_CW_INLINE cw_nxoi_t
nxo_integer_get(cw_nxo_t *a_nxo)
{
	_cw_check_ptr(a_nxo);
	_cw_dassert(a_nxo->magic == _CW_NXO_MAGIC);
	_cw_assert(nxo_type_get(a_nxo) == NXOT_INTEGER);

	return a_nxo->o.integer.i;
}

_CW_INLINE void
nxo_integer_set(cw_nxo_t *a_nxo, cw_nxoi_t a_val)
{
	_cw_check_ptr(a_nxo);
	_cw_dassert(a_nxo->magic == _CW_NXO_MAGIC);
	_cw_assert(nxo_type_get(a_nxo) == NXOT_INTEGER);

	a_nxo->o.integer.i = a_val;
}
#endif	/* (defined(_CW_USE_INLINES) || defined(_NXO_INTEGER_C_)) */

==> onyx-3.0.2.tgz: include/libonyx/nxo_integer.h <==
/* -*- mode: c ; c-file-style: "canonware-c-style" -*-
 ******************************************************************************
 *
 * Copyright (C) 1996-2002 Jason Evans <jasone@canonware.com>.
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice(s), this list of conditions and the following disclaimer
 *    unmodified other than the allowable addition of one or more
 *    copyright notices.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice(s), this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER(S) ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER(S) BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************
 *
 * Version: Onyx 3.0.2
 *
 ******************************************************************************/

#ifndef CW_USE_INLINES
void
nxo_integer_new(cw_nxo_t *a_nxo, cw_nxoi_t a_val);

cw_nxoi_t
nxo_integer_get(cw_nxo_t *a_nxo);

void
nxo_integer_set(cw_nxo_t *a_nxo, cw_nxoi_t a_val);
#endif

#if (defined(CW_USE_INLINES) || defined(CW_NXO_INTEGER_C_))
CW_INLINE void
nxo_integer_new(cw_nxo_t *a_nxo, cw_nxoi_t a_val)
{
    cw_check_ptr(a_nxo);

    nxo_p_new(a_nxo, NXOT_INTEGER);
    a_nxo->o.integer.i = a_val;
}

CW_INLINE cw_nxoi_t
nxo_integer_get(cw_nxo_t *a_nxo)
{
    cw_check_ptr(a_nxo);
    cw_dassert(a_nxo->magic == CW_NXO_MAGIC);
    cw_assert(nxo_type_get(a_nxo) == NXOT_INTEGER);

    return a_nxo->o.integer.i;
}

CW_INLINE void
nxo_integer_set(cw_nxo_t *a_nxo, cw_nxoi_t a_val)
{
    cw_check_ptr(a_nxo);
    cw_dassert(a_nxo->magic == CW_NXO_MAGIC);
    cw_assert(nxo_type_get(a_nxo) == NXOT_INTEGER);

    a_nxo->o.integer.i = a_val;
}
#endif /* (defined(CW_USE_INLINES) || defined(CW_NXO_INTEGER_C_)) */
